==> zio-aws-macie2_2.12-5.17.257.1-sources.jar: zio/aws/macie2/model/UpdateClassificationJobRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class UpdateClassificationJobRequest(
    jobId: __string,
    jobStatus: zio.aws.macie2.model.JobStatus
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.UpdateClassificationJobRequest = {
    import UpdateClassificationJobRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.UpdateClassificationJobRequest
      .builder()
      .jobId(jobId: java.lang.String)
      .jobStatus(jobStatus.unwrap)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.UpdateClassificationJobRequest.ReadOnly =
    zio.aws.macie2.model.UpdateClassificationJobRequest.wrap(buildAwsValue())
}
object UpdateClassificationJobRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.UpdateClassificationJobRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.UpdateClassificationJobRequest =
      zio.aws.macie2.model.UpdateClassificationJobRequest(jobId, jobStatus)
    def jobId: __string
    def jobStatus: zio.aws.macie2.model.JobStatus
    def getJobId: ZIO[Any, Nothing, __string] = ZIO.succeed(jobId)
    def getJobStatus: ZIO[Any, Nothing, zio.aws.macie2.model.JobStatus] =
      ZIO.succeed(jobStatus)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.UpdateClassificationJobRequest
  ) extends zio.aws.macie2.model.UpdateClassificationJobRequest.ReadOnly {
    override val jobId: __string = impl.jobId(): __string
    override val jobStatus: zio.aws.macie2.model.JobStatus =
      zio.aws.macie2.model.JobStatus.wrap(impl.jobStatus())
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.UpdateClassificationJobRequest
  ): zio.aws.macie2.model.UpdateClassificationJobRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-macie2_2.13-5.17.122.1-sources.jar: zio/aws/macie2/model/UpdateClassificationJobRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class UpdateClassificationJobRequest(
    jobId: __string,
    jobStatus: zio.aws.macie2.model.JobStatus
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.UpdateClassificationJobRequest = {
    import UpdateClassificationJobRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.UpdateClassificationJobRequest
      .builder()
      .jobId(__string.unwrap(jobId): java.lang.String)
      .jobStatus(jobStatus.unwrap)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.UpdateClassificationJobRequest.ReadOnly =
    zio.aws.macie2.model.UpdateClassificationJobRequest.wrap(buildAwsValue())
}
object UpdateClassificationJobRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.UpdateClassificationJobRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.UpdateClassificationJobRequest =
      zio.aws.macie2.model.UpdateClassificationJobRequest(jobId, jobStatus)
    def jobId: __string
    def jobStatus: zio.aws.macie2.model.JobStatus
    def getJobId: ZIO[Any, Nothing, __string] = ZIO.succeed(jobId)
    def getJobStatus: ZIO[Any, Nothing, zio.aws.macie2.model.JobStatus] =
      ZIO.succeed(jobStatus)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.UpdateClassificationJobRequest
  ) extends zio.aws.macie2.model.UpdateClassificationJobRequest.ReadOnly {
    override val jobId: __string =
      zio.aws.macie2.model.primitives.__string(impl.jobId())
    override val jobStatus: zio.aws.macie2.model.JobStatus =
      zio.aws.macie2.model.JobStatus.wrap(impl.jobStatus())
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.UpdateClassificationJobRequest
  ): zio.aws.macie2.model.UpdateClassificationJobRequest.ReadOnly = new Wrapper(
    impl
  )
}
